Project hosting with Launchpad
==============================

`Launchpad`_ hosts the Zun project. The Zun project homepage on
Launchpad is http://launchpad.net/zun.


Mailing list
------------

The mailing list email is ``openstack@lists.openstack.org``. This is a common
mailing list across the OpenStack projects. To participate in the mailing list:

#. Subscribe to the list at
http://lists.openstack.org/cgi-bin/mailman/listinfo/openstack

The mailing list archives are at http://lists.openstack.org/pipermail/openstack/.


Bug tracking
------------

Report Zun bugs at https://bugs.launchpad.net/zun

Launchpad credentials
---------------------

Creating a login on Launchpad is important even if you don't use the Launchpad
site itself, since Launchpad credentials are used for logging in on several
OpenStack-related sites.

.. only:: html

   These sites include:

    * `Wiki`_
    * Gerrit (see :doc:`gerrit`)
    * Jenkins (see :doc:`jenkins`)

Feature requests (Blueprints)
-----------------------------

Zun uses Launchpad Blueprints to track feature requests. Blueprints are at
https://blueprints.launchpad.net/zun.

Technical support (Answers)
---------------------------

Zun no longer uses Launchpad Answers to track Zun technical support questions.

Note that `Ask OpenStack`_ (which is not hosted on Launchpad) can
be used for technical support requests.

.. _Launchpad: https://launchpad.net
.. _Wiki: https://wiki.openstack.org/wiki/Main_Page
.. _Zun Team: https://launchpad.net/~zun
.. _OpenStack Team: https://launchpad.net/~openstack
.. _Ask OpenStack: https://ask.openstack.org
